"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var GroupsProcessor = /** @class */ (function () {
    function GroupsProcessor() {
        // Stores the order of components' grouping while traversing the components tree
        this.groupsStack = [];
        // Following properties are used to determine the group index in children list
        // Number of children collapsed into the groups for each parent node
        this.groupedChildren = new Map();
        // Number of groups in each parent node
        this.groupsCount = new Map();
    }
    GroupsProcessor.prototype.scheduleGroup = function (parentNode, childNode) {
        var groupedChildrenCount = this.groupedChildren.get(parentNode) || 0;
        var groupsCreatedCount = this.groupsCount.get(parentNode) || 0;
        this.groupsStack.push(childNode);
        this.groupsCount.set(parentNode, groupsCreatedCount + 1);
        this.groupedChildren.set(parentNode, groupedChildrenCount + childNode.children.length);
        childNode.order = parentNode.children.length - groupedChildrenCount + groupsCreatedCount + 1;
        childNode.children.forEach(function (child) {
            parentNode.appendChild(child);
        });
    };
    GroupsProcessor.prototype.mountGroups = function () {
        // As we only can append group to real Figma node, we have to reverse the list
        // and we then we will group items top-down
        this.groupsStack.reverse().forEach(function (group) {
            group.figmaNode = figma.group(group.children, group.children[0].parent, group.order);
            group.didMount();
        });
        this.groupsStack = [];
    };
    return GroupsProcessor;
}());
exports.GroupsProcessor = GroupsProcessor;
//# sourceMappingURL=groupsProcessor.js.map